WFPC2 ImageObjects — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »

# WFPC2 ImageObjects

class `drizzlepac.wfpc2Data.` `WFPC2InputImage`(filename, group=None)

  Bases: `drizzlepac.imageObject.imageObject`

  `buildMask`(chip, bits=0, write=False)

    Build masks as specified in the user parameters found in the configObj object.

  `doUnitConversions`()

    Apply unit conversions to all the chips, ignoring the group parameter. This insures that all the chips get the same conversions when this gets done, even if only 1 chip was specified to be processed.

  `find_DQ_extension`()

    Return the suffix for the data quality extension and the name of the file which that DQ extension should be read from.

  `getEffGain`()

    Method used to return the effective gain of a instrument’s detector.

    Returns :
    | gain : float The effective gain.

  `getReadNoise`(exten)

    Method for returning the readnoise of a detector (in counts).

    Returns :
    | readnoise : float The readnoise of the detector in units of counts/electrons.

  `getdarkcurrent`(exten)

    Return the dark current for the WFPC2 detector. This value will be contained within an instrument specific keyword. The value in the image header will be converted to units of electrons.

    Returns :
    | darkcurrent : float Dark current for the WFPC3 detector in units of counts/electrons.

  `getflat`(chip)

    Method for retrieving a detector’s flat field.

    Returns :
    | flat : array The flat-field array in the same shape as the input image.

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

  `SEPARATOR` = '_'

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »